Traits
Functions
- fix_
nested_ tables - insert_
local_ version_ if_ absent - If a local path is provided but no version is present, attempts to fetch the version from the local Cargo.toml and inserts it.
- is_
dependencies_ key - Checks if a table key ends with “dependencies”
- pick_
highest_ version - pin_
from_ lock_ or_ warn - pin_
wildcard_ dependencies_ in_ table - Iterates over a TOML
TeTable(i.e.,[dependencies]or similar), and pins any wildcard dependencies found. This ensures that workspace dependencies do not remain*when building or releasing. - pin_
wildcard_ inline_ table_ dependency - pin_
wildcard_ string_ dependency - Pins a wildcard string dependency (e.g.
serde = "*") from the lockfile if its version is*. If no entry is found in the lockfile, logs a warning and leaves it as*. - pin_
wildcard_ table_ dependency - Pins a wildcard sub-table dependency (e.g.
[dependencies.somecrate] version="*", path="..."). If the dependency has a local path, usesGetVersionOfLocalDepto retrieve the version. Otherwise, falls back to the lockfile. - pin_
wildcards_ in_ doc - replace_
wildcard_ version_ with_ local - If a local path is provided and the version is
"*", fetches the local version and replaces the wildcard.